# COMPAS Rhino UI

This package containts a collection of components to build user interfaces in Rhino 8+ for COMPAS tools.

> [!WARNING]  
> This package can only be used inside of Rhino 8.
> In other environments it will simply not work...

## Installation

Stable releases can be installed from PyPI.

```bash
pip install compas_rui
```

To install the latest version for development, do:

```bash
git clone https://github.com/blockresearchgroup/compas_rui.git
cd compas_rui
pip install -e ".[dev]"
```

## Documentation

For further "getting started" instructions, a tutorial, examples, and an API reference,
please check out the online documentation here: [COMPAS Rhino UI docs](https://blockresearchgroup.github.io/compas_rui)

## Issue Tracker

If you find a bug or if you have a problem with running the code, please file an issue on the [Issue Tracker](https://github.com/blockresearchgroup/compas_rui/issues).
